@@ -1,17 +1,19 @@
 import colorsys
 
+from .units import Unit
+
 
 class Color:
     def __init__(
         self, red: int = 0, green: int = 0, blue: int = 0, alpha: float = 1.0
     ) -> None:
-        self.red = red
-        self.green = green
-        self.blue = blue
-        self.alpha = 1.0 if alpha is None else alpha
+        self.r = red
+        self.g = green
+        self.b = blue
+        self.a = 1.0 if alpha is None else alpha
 
     def __str__(self):
-        return f"rgba({self.red},{self.green},{self.blue},{self.alpha})"
+        return f"rgba({self.r},{self.g},{self.b},{self.a})"
 
     @classmethod
     def from_hsv(
@@ -21,7 +23,7 @@ class Color:
         return Color(int(r * 255), int(g * 255), int(b * 255), alpha)
 
     def to_hsv(self):
-        return colorsys.rgb_to_hsv(self.red / 255, self.green / 255, self.blue / 255)
+        return colorsys.rgb_to_hsv(self.r / 255, self.g / 255, self.b / 255)
 
     @classmethod
     def from_hls(
@@ -31,15 +33,18 @@ class Color:
         return Color(int(r * 255), int(g * 255), int(b * 255), alpha)
 
     def to_hls(self):
-        return colorsys.rgb_to_hls(self.red / 255, self.green / 255, self.blue / 255)
+        return colorsys.rgb_to_hls(self.r / 255, self.g / 255, self.b / 255)
+
+    def to_rgb(self):
+        return self.r, self.g, self.b
 
     def saturated(self, saturation: float) -> "Color":
         h, _, v = self.to_hsv()
-        return Color.from_hsv(h, saturation, v, self.alpha)
+        return Color.from_hsv(h, saturation, v, self.a)
 
     def lit(self, lightness: float) -> "Color":
         h, _, s = self.to_hls()
-        return Color.from_hls(h, lightness, s, self.alpha)
+        return Color.from_hls(h, lightness, s, self.a)
 
     @classmethod
     def red(cls, lightness: float = 1.0):
@@ -56,3 +61,18 @@ class Color:
     @classmethod
     def gray(cls, lightness: float = 1.0):
         return Color(255, 255, 255, 1).lit(lightness)
+
+    @staticmethod
+    def palette(start: "Color", end: "Color", steps: int, space="hls"):
+        from_space = getattr(Color, f"from_{space}")
+        to_space = getattr(Color, f"to_{space}")
+
+        start_values = to_space(start)
+        end_values = to_space(end)
+        step_values = [
+            list(Unit.scale(float, s, e, steps))
+            for s, e in zip(start_values, end_values)
+        ]
+
+        for tuple in zip(*step_values):
+            yield from_space(*tuple)
